// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT license.
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const path = require("path");
const vscode = require("vscode");
const common_backend_1 = require("common-backend");
const util_1 = require("util");
function activate(context) {
    let current = undefined;
    context.subscriptions.push(vscode.commands.registerCommand('sanddance.view', (fileUri) => {
        const columnToShowIn = vscode.window.activeTextEditor ? vscode.window.activeTextEditor.viewColumn : undefined;
        const uriFsPath = fileUri.fsPath;
        //only allow one SandDance at a time
        if (current && current.uriFsPath !== uriFsPath) {
            current.panel.dispose();
            current = undefined;
        }
        if (current) {
            //TODO: registerWebviewPanelSerializer to hydrate state
            // If we already have a panel, show it in the target column
            current.panel.reveal(columnToShowIn);
        }
        else {
            // Otherwise, create a new panel
            current = common_backend_1.newPanel(context, uriFsPath);
            current.panel.onDidDispose(() => {
                current = undefined;
            }, null, context.subscriptions);
            // Handle messages from the webview
            current.panel.webview.onDidReceiveMessage(message => {
                switch (message.command) {
                    case 'getFileContent': {
                        vscode.workspace.fs.readFile(fileUri).then(uint8array => {
                            if (current && current.panel.visible) {
                                //TODO string type of dataFile
                                const dataFile = {
                                    type: path.extname(uriFsPath).substring(1),
                                    rawText: new util_1.TextDecoder().decode(uint8array)
                                };
                                const compactUI = context.globalState.get('compactUI');
                                current.panel.webview.postMessage({ command: 'gotFileContent', dataFile, compactUI });
                            }
                        });
                        break;
                    }
                    case 'setCompactUI': {
                        context.globalState.update('compactUI', message.compactUI);
                        break;
                    }
                }
            }, undefined, context.subscriptions);
        }
    }));
}
exports.activate = activate;
function deactivate() {
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map