var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT license.
var SandDanceApp;
(function (SandDanceApp) {
    SandDanceApp.strings = {
        labelPreferences: 'Preferences',
        labelCompactUI: 'Compact UI',
        labelCompactUIDescription: 'Compact UI hides collapses labels on dropdown menus.'
    };
})(SandDanceApp || (SandDanceApp = {}));
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT license.
var SandDance = SandDanceExplorer.SandDance;
var VegaDeckGl = SandDance.VegaDeckGl;
var SandDanceApp;
(function (SandDanceApp) {
    SandDanceExplorer.use(FluentUIReact, React, ReactDOM, vega, deck, deck, luma);
    function getTextcolor() {
        return getComputedStyle(document.body).color;
    }
    function getThemePalette(darkTheme) {
        var theme = darkTheme ? 'dark-theme' : '';
        return SandDanceExplorer.themePalettes[theme];
    }
    function getViewerOptions(darkTheme) {
        var color = getTextcolor();
        var viewerOptions = {
            colors: __assign(__assign({}, SandDanceExplorer.getColorSettingsFromThemePalette(getThemePalette(darkTheme))), { axisLine: color, axisText: color, hoveredCube: color })
        };
        return viewerOptions;
    }
    function getVscodeThemeClassName() {
        var classList = [].slice.apply(document.body.classList);
        var prefixed = classList.filter(function (className) { return className.indexOf('vscode') === 0; });
        if (prefixed.length) {
            return prefixed[0];
        }
    }
    var z = 'z'.charCodeAt(0);
    var Z = 'Z'.charCodeAt(0);
    var App = /** @class */ (function (_super) {
        __extends(App, _super);
        function App(props) {
            var _this = _super.call(this, props) || this;
            _this.vscode = acquireVsCodeApi();
            _this.state = {
                compactUI: false,
                darkTheme: null
            };
            _this.viewerOptions = getViewerOptions(_this.state.darkTheme);
            _this.handlers = {
                message: function (event) {
                    // Handle the message inside the webview
                    var message = event.data;
                    switch (message.command) {
                        case 'gotFileContent':
                            if (_this.explorer) {
                                _this.explorer.load(message.dataFile);
                                _this.setState({ compactUI: message.compactUI });
                            }
                            //TODO: hydrate state
                            break;
                    }
                },
                resize: function (e) {
                    _this.explorer && _this.explorer.resize();
                },
                keyup: function (e) {
                    //look for CTRL Z or CTRL SHIFT Z
                    if (e.ctrlKey && (e.keyCode === z || e.keyCode === Z)) {
                        if (e.shiftKey) {
                            _this.explorer.redo();
                        }
                        else {
                            _this.explorer.undo();
                        }
                    }
                }
            };
            return _this;
        }
        App.prototype.wireEventHandlers = function (add) {
            for (var key in this.handlers) {
                if (add) {
                    window.addEventListener(key, this.handlers[key]);
                }
                else {
                    window.removeEventListener(key, this.handlers[key]);
                }
            }
        };
        App.prototype.checkForDarkTheme = function () {
            var vscodeThemeClassName = getVscodeThemeClassName();
            var darkTheme = vscodeThemeClassName.indexOf('dark') >= 0;
            this.viewerOptions = getViewerOptions(darkTheme);
            if (this.state.darkTheme !== darkTheme && this.explorer) {
                this.explorer.updateViewerOptions(this.viewerOptions);
                if (this.explorer.viewer) {
                    this.explorer.viewer.renderSameLayout(this.explorer.viewerOptions);
                }
            }
            FluentUIReact.loadTheme({ palette: getThemePalette(darkTheme) });
            this.setState({ darkTheme: darkTheme });
        };
        App.prototype.mounted = function (explorer) {
            var _this = this;
            this.explorer = explorer;
            this.wireEventHandlers(true);
            this.vscode.postMessage({
                command: 'getFileContent'
            });
            this.checkForDarkTheme();
            new MutationObserver(function (mutationRecords) {
                _this.checkForDarkTheme();
            }).observe(document.body, { attributeFilter: ['class'] });
        };
        App.prototype.render = function () {
            var _this = this;
            return (React.createElement(SandDanceExplorer.Explorer, { logoClickUrl: "https://microsoft.github.io/SandDance/", theme: this.state.darkTheme && 'dark-theme', viewerOptions: this.viewerOptions, initialView: "2d", mounted: function (e) { return _this.mounted(e); }, compactUI: this.state.compactUI, additionalSettings: [
                    {
                        groupLabel: SandDanceApp.strings.labelPreferences,
                        children: (React.createElement(FluentUIReact.Toggle, { label: SandDanceApp.strings.labelCompactUI, title: SandDanceApp.strings.labelCompactUIDescription, checked: this.state.compactUI, onChange: function (e, checked) {
                                _this.vscode.postMessage({
                                    command: 'setCompactUI',
                                    compactUI: checked
                                });
                                _this.setState({ compactUI: checked });
                            } }))
                    }
                ] }));
        };
        return App;
    }(React.Component));
    SandDanceApp.App = App;
    var app = React.createElement(App);
    ReactDOM.render(app, document.getElementById('app'));
})(SandDanceApp || (SandDanceApp = {}));
